package controllers

import (
	"errors"
	"strconv"
	"voting/models"
)

// VotingController 是投票 controller
type VotingController struct {
	BaseController
	db *models.VotingModel
}

// Constructor 初始化
func (c *VotingController) Constructor() {
	c.db = new(models.VotingModel)
}

// @Title List
// @Description 获取报名人员列表
// @Param   actid   path   string  true	"活动ID"
// @Param   page   query   int  false	"分页"
// @Param   q   query   string  false	"查询内容, 不填即为查询全部"
// @Param   tab   query   int  false	"列表类型, 1 为最新上传, 2 为 Top50"
// @Success 200 [object] models.MemInfo
// @Failure 403 message of error
// @router /members [get]
func (c *VotingController) List() {
	// 活动
	actID, _ := c.GetInt(":actid")

	// 分页
	page, _ := c.GetInt("page")
	if page < 1 {
		page = 1
	}
	page -= 1

	// tab 类型
	tab, _ := c.GetInt("tab")

	// 搜索条件
	search := c.GetString("q")
	name := search
	memID, err := strconv.Atoi(search)
	if err != nil {
		memID = 0
	} else {
		name = ""
	}

	list, err := c.db.List(actID, name, memID, tab, page)
	if err != nil {
		c.ResponseError(errors.New("查询列表失败, 请重试"))
	}

	c.ResponseJSON(list)
}
