package models

import (
	"voting/utils"

	"github.com/astaxie/beego"
	_ "github.com/go-sql-driver/mysql"
	"github.com/go-xorm/xorm"
)

var (
	DBEngine *xorm.Engine
	logger   *utils.Logger
)

func InitDB() {
	DBEngine = NewDBEngine()
	logger = utils.GetLogger()
}

// NewDBEngine 初始化数据库连接
func NewDBEngine() *xorm.Engine {
	dbType := "mysql"
	dns := getMySQLDNS()

	engine, err := xorm.NewEngine(dbType, dns)
	// engine.ShowSQL()

	if err != nil {
		panic(err)
	}

	return engine
}

func getMySQLDNS() (dns string) {
	conProt := beego.AppConfig.DefaultString("db::con_protocol", "tcp")
	dbAddr := beego.AppConfig.DefaultString("db::db_addr", "localhost")
	dbPort := beego.AppConfig.DefaultString("db::db_port", "3306")
	userName := beego.AppConfig.DefaultString("db::username", "root")
	password := beego.AppConfig.String("db::password")
	database := beego.AppConfig.String("db::database")
	charSet := beego.AppConfig.DefaultString("db::char_set", "utf8")

	dns = userName

	if len(password) > 0 {
		dns += ":" + password
	}

	dns += "@" + conProt + "(" + dbAddr + ":" + dbPort + ")" + "/" + database + "?charset=" + charSet

	return
}
