package utils

import (
	"errors"
	"net/http"
	"strings"

	"github.com/aliyun/aliyun-oss-go-sdk/oss"
	"github.com/astaxie/beego"
)

var ossCli *oss.Client

func OssInit() {
	logger := GetLogger()

	cert, err := beego.AppConfig.GetSection("alioss")
	if err != nil {
		logger.Error("读取阿里 OSS 配置失败: ", err)
		return
	}

	OssClientSingleton(cert["Endpoint"], cert["AccessKeyId"], cert["AccessKeySecret"])
}

func OssClientSingleton(endpoint, accessKeyID, accessKeySecret string) {
	if ossCli == nil {
		var err error
		logger := GetLogger()
		ossCli, err = oss.New(endpoint, accessKeyID, accessKeySecret)
		if err != nil {
			logger.Error("初始化阿里 OSS 失败: ", err)
		}
	}
}

// GetOssClient 获取 OSS 客户端
func GetOssClient() *oss.Client {
	return ossCli
}

// UploadFileToBucket 简单上传文件
func UploadFileToBucket(req *http.Request, fromFront string, nameSuffix ...string) (string, error) {
	logger := GetLogger()
	bucket := beego.AppConfig.String("alioss::Bucket")
	endpoint := beego.AppConfig.String("alioss::Endpoint")

	if ossCli == nil {
		logger.Error("未成功初始化OSS 客户端")
		return "", errors.New("未成功初始化OSS 客户端")
	}

	bkt, err := ossCli.Bucket(bucket)
	if err != nil {
		logger.Error("初始化OSS Bucket 失败: ", err)
		return "", errors.New("初始化OSS Bucket 失败")
	}

	file, fh, err := req.FormFile(fromFront)
	if err != nil {
		logger.Error("读取文件失败: ", err)
		return "", errors.New("未读取到文件或读取失败")
	}
	defer file.Close()

	fname := fh.Filename
	if len(nameSuffix) > 0 && nameSuffix[0] != "" {
		fArr := strings.Split(fname, ".")
		fArr[0] = fArr[0] + nameSuffix[0]
		fname = strings.Join(fArr, ".")
	}

	err = bkt.PutObject(fname, file)
	if err != nil {
		logger.Error("上传文件到 OSS 失败: ", err)
		return "", errors.New("上传文件到 OSS 失败")
	}

	return strings.Join([]string{
		"http://",
		bucket + ".",
		endpoint + "/",
		fname,
	}, ""), nil
}
