package utils

import (
	"github.com/astaxie/beego"
	"github.com/zjxpcyc/wechat/wx"
)

var wxClients *wx.Client

type WechatUser struct {
	OpenID     string  `json:"openid"`
	NickName   string  `json:"nickname"`
	Sex        float64 `json:"sex"`
	Province   string  `json:"province"`
	City       string  `json:"city"`
	Country    string  `json:"country"`
	HeadImgURL string  `json:"headimgurl"`
	UnionID    string  `json:"unionid"`
}

// WxClientSingleton 初始化
func WxClientSingleton(cert map[string]string) {
	if wxClients == nil {
		wxClients = wx.NewClient(cert)
	}
}

func GetWxClient() *wx.Client {
	return wxClients
}

// GetWxAppID 获取微信ID
func GetWxAppID() string {
	if wxClients != nil {
		return wxClients.GetAppID()
	} else {
		return ""
	}
}

func WechatInit() {
	logger := GetLogger()
	wx.SetLogInst(logger)

	cert, err := beego.AppConfig.GetSection("wechat")
	if err != nil {
		logger.Error("初始化微信失败: ", err)
	}

	WxClientSingleton(cert)
}

// MapToWechatUser 映射微信人员
func MapToWechatUser(data map[string]interface{}) *WechatUser {
	subscribe, has := data["subscribe"]
	if has {
		if subscribe == nil {
			return nil
		}

		sub := subscribe.(float64)
		if sub == 0 {
			return nil
		}
	}

	user := WechatUser{
		OpenID: data["openid"].(string),
	}

	if data["sex"] != nil {
		user.Sex = data["sex"].(float64)
	}

	if data["nickname"] != nil {
		user.NickName = data["nickname"].(string)
	}

	if data["province"] != nil {
		user.Province = data["province"].(string)
	}

	if data["city"] != nil {
		user.City = data["city"].(string)
	}

	if data["country"] != nil {
		user.Country = data["country"].(string)
	}

	if data["headimgurl"] != nil {
		user.HeadImgURL = data["headimgurl"].(string)
	}

	if data["unionid"] != nil {
		user.UnionID = data["unionid"].(string)
	}

	return &user
}
